@@ -1,3 +1,8 @@
+try:
+    from zope.component.hooks import getSite
+    getSite  #Pyflakes
+except ImportError:
+    from zope.app.component.hooks import getSite
 from zope.interface import implements
 from zope.schema.fieldproperty import FieldProperty
 from zope.component import getUtility
@@ -12,7 +17,6 @@ from Products.Archetypes.Field import ImageField
 from Products.CMFCore.utils import getToolByName
 from Products.CMFCore.interfaces._content import IFolderish
 from plone.app.layout.navigation.root import getNavigationRootObject
-from Products.CMFCore.interfaces import ISiteRoot
 try:
     import json
 except:
@@ -717,10 +721,18 @@ class TinyMCE(SimpleItem):
         else:
             results['contextmenu'] = False
 
+        portal = getSite()
+        results['portal_url'] = aq_inner(portal).absolute_url()
+        nav_root = getNavigationRootObject(context, portal)
+        results['navigation_root_url'] = nav_root.absolute_url()
+
         if self.content_css and self.content_css.strip() != "":
             results['content_css'] = self.content_css
         else:
-            results['content_css'] = self.absolute_url() + """/@@tinymce-getstyle"""
+            results['content_css'] = '/'.join([
+                results['portal_url'],
+                self.getId(),
+                "@@tinymce-getstyle"])
 
         if self.link_using_uids:
             results['link_using_uids'] = True
@@ -743,11 +755,6 @@ class TinyMCE(SimpleItem):
 
         results['entity_encoding'] = self.entity_encoding
 
-        portal = getUtility(ISiteRoot)
-        results['portal_url'] =  aq_inner(portal).absolute_url()
-        nav_root = getNavigationRootObject(context, portal)
-        results['navigation_root_url'] = nav_root.absolute_url()
-
         props = getToolByName(self, 'portal_properties')
         livesearch = props.site_properties.getProperty('enable_livesearch', False)
         if livesearch:
